<?php
/**
 * A single course loop rating
 *
 * @package Tutor\Templates
 * @subpackage CourseLoopPart
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
global $post, $authordata;
$course_id         = $post->ID;
$profile_url       = tutor_utils()->profile_url( $authordata->ID, true );
$course_categories = get_tutor_course_categories( $course_id );
$show_course_ratings = apply_filters( 'tutor_show_course_ratings', true, get_the_ID() );
?>

<div class="tutor-course-ratings d-flex align-items-center justify-content-between">
	
    <div class="course-block_two-lower te-author__box">
        <div>
            <a href="<?php echo esc_url( $profile_url ); ?>" class="tutor-d-flex">
                <?php echo wp_kses( tutor_utils()->get_tutor_avatar( $post->post_author ), tutor_utils()->allowed_avatar_tags() ); ?>
            </a>
        </div>
    
        <div class="d-flex flex-column">
            <div class="te-author__thumb">
				<?php esc_html_e( 'By', 'alquran' ); ?>
                <a href="<?php echo esc_url( $profile_url ); ?>"><?php echo esc_html( get_the_author() ); ?></a>
    		</div>
            <?php if ( ! empty( $course_categories ) && is_array( $course_categories ) && count( $course_categories ) ) : ?>
                <div class="te-category__author">
				<?php esc_html_e( 'In', 'alquran' ); ?>
                <?php
                    $category_links = array();
                foreach ( $course_categories as $course_category ) :
                    $category_name    = $course_category->name;
                    $category_link    = get_term_link( $course_category->term_id );
                    $category_links[] = wp_sprintf( '<a href="%1$s">%2$s</a>', esc_url( $category_link ), esc_html( $category_name ) );
                    endforeach;
                    echo implode( ', ', $category_links ); //phpcs:ignore --contain safe data
                ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
	
	<?php if ( $show_course_ratings ) : ?>
	<div class="tutor-ratings">
		<div class="tutor-ratings-stars">
			<?php
				$course_rating = tutor_utils()->get_course_rating();
				tutor_utils()->star_rating_generator_course( $course_rating->rating_avg );
			?>
		</div>

		<?php if ( $course_rating->rating_avg > 0 ) : ?>
			<div class="tutor-ratings-average">
				<?php echo esc_html( apply_filters( 'tutor_course_rating_average', $course_rating->rating_avg ) ); ?>
			</div>
			<div class="tutor-ratings-count">
				(<?php echo esc_html( $course_rating->rating_count > 0 ? $course_rating->rating_count : 0 ); ?>)
			</div>
		<?php endif; ?>
	</div>
	<?php endif; ?>
    
</div>
<?php do_action( 'tutor_after_course_loop_rating', get_the_ID() ); ?>
